==> jc-1.4.0.tar.gz: javax/swing/InternalFrameFocusTraversalPolicy.h <==
// public abstract class javax.swing.InternalFrameFocusTraversalPolicy

// class file dependencies
// @dep_class aa7caa0df83b76f6 java_awt_FocusTraversalPolicy
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3cd22a3f5d3a5e41 javax_swing_InternalFrameFocusTraversalPolicy

// header file dependencies
// @dep_header java_awt_FocusTraversalPolicy

#include "java/awt/FocusTraversalPolicy.h"

#ifndef _JC_javax_swing_InternalFrameFocusTraversalPolicy_H_
#define _JC_javax_swing_InternalFrameFocusTraversalPolicy_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JInternalFrame$object;

// Typedefs
typedef struct _jc_javax_swing_InternalFrameFocusTraversalPolicy$sub_refs	_jc_javax_swing_InternalFrameFocusTraversalPolicy$sub_refs;
typedef struct _jc_javax_swing_InternalFrameFocusTraversalPolicy$sub_nonrefs	_jc_javax_swing_InternalFrameFocusTraversalPolicy$sub_nonrefs;
typedef struct _jc_javax_swing_InternalFrameFocusTraversalPolicy$refs	_jc_javax_swing_InternalFrameFocusTraversalPolicy$refs;
typedef struct _jc_javax_swing_InternalFrameFocusTraversalPolicy$nonrefs	_jc_javax_swing_InternalFrameFocusTraversalPolicy$nonrefs;
typedef struct _jc_javax_swing_InternalFrameFocusTraversalPolicy$object	_jc_javax_swing_InternalFrameFocusTraversalPolicy$object;

typedef const struct _jc_javax_swing_InternalFrameFocusTraversalPolicy$vmethods	_jc_javax_swing_InternalFrameFocusTraversalPolicy$vmethods;
typedef const struct _jc_javax_swing_InternalFrameFocusTraversalPolicy$vtable	_jc_javax_swing_InternalFrameFocusTraversalPolicy$vtable;
typedef const struct _jc_javax_swing_InternalFrameFocusTraversalPolicy$vtype	_jc_javax_swing_InternalFrameFocusTraversalPolicy$vtype;

// Constructors
extern void _jc_javax_swing_InternalFrameFocusTraversalPolicy$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_InternalFrameFocusTraversalPolicy$object *);

// Virtual methods
extern struct _jc_java_awt_Component$object *_jc_javax_swing_InternalFrameFocusTraversalPolicy$method$getInitialComponent$4f44bd9e24dac6b8(_jc_env *, struct _jc_javax_swing_InternalFrameFocusTraversalPolicy$object *, struct _jc_javax_swing_JInternalFrame$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_InternalFrameFocusTraversalPolicy$method_info$getInitialComponent$4f44bd9e24dac6b8;

// Virtual methods structure
struct _jc_javax_swing_InternalFrameFocusTraversalPolicy$vmethods {
	struct _jc_java_awt_Component$object	*(*getInitialComponent$4f44bd9e24dac6b8)(_jc_env *, struct _jc_javax_swing_InternalFrameFocusTraversalPolicy$object *, struct _jc_javax_swing_JInternalFrame$object *);
};

// Vtable
struct _jc_javax_swing_InternalFrameFocusTraversalPolicy$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_FocusTraversalPolicy$vmethods	java_awt_FocusTraversalPolicy;
	_jc_javax_swing_InternalFrameFocusTraversalPolicy$vmethods	javax_swing_InternalFrameFocusTraversalPolicy;
};

// Vtype
struct _jc_javax_swing_InternalFrameFocusTraversalPolicy$vtype {
	_jc_type			type;
	_jc_javax_swing_InternalFrameFocusTraversalPolicy$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_InternalFrameFocusTraversalPolicy$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_InternalFrameFocusTraversalPolicy$refs {
    _jc_javax_swing_InternalFrameFocusTraversalPolicy$sub_refs	javax_swing_InternalFrameFocusTraversalPolicy;
    _jc_java_awt_FocusTraversalPolicy$sub_refs	java_awt_FocusTraversalPolicy;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_InternalFrameFocusTraversalPolicy$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_InternalFrameFocusTraversalPolicy$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_FocusTraversalPolicy$sub_nonrefs	java_awt_FocusTraversalPolicy;
    _jc_javax_swing_InternalFrameFocusTraversalPolicy$sub_nonrefs	javax_swing_InternalFrameFocusTraversalPolicy;
};

// Object instance structure
struct _jc_javax_swing_InternalFrameFocusTraversalPolicy$object {
	_jc_javax_swing_InternalFrameFocusTraversalPolicy$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_InternalFrameFocusTraversalPolicy$vtype	*vtype;
	_jc_javax_swing_InternalFrameFocusTraversalPolicy$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_InternalFrameFocusTraversalPolicy$vtype _jc_javax_swing_InternalFrameFocusTraversalPolicy$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_InternalFrameFocusTraversalPolicy, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_InternalFrameFocusTraversalPolicy$class_object;

#endif	/* _JC_javax_swing_InternalFrameFocusTraversalPolicy_H_ */

==> jc-1.4.6.tar.gz: javax/swing/InternalFrameFocusTraversalPolicy.h <==
// public abstract class javax.swing.InternalFrameFocusTraversalPolicy

// class file dependencies
// @dep_class aa7caa0df83b76f6 java_awt_FocusTraversalPolicy
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3cd22a3f5d3a5e41 javax_swing_InternalFrameFocusTraversalPolicy

// header file dependencies
// @dep_header java_awt_FocusTraversalPolicy

#include "java/awt/FocusTraversalPolicy.h"

#ifndef _JC_javax_swing_InternalFrameFocusTraversalPolicy_H_
#define _JC_javax_swing_InternalFrameFocusTraversalPolicy_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JInternalFrame$object;

// Typedefs
typedef struct _jc_javax_swing_InternalFrameFocusTraversalPolicy$sub_refs	_jc_javax_swing_InternalFrameFocusTraversalPolicy$sub_refs;
typedef struct _jc_javax_swing_InternalFrameFocusTraversalPolicy$sub_nonrefs	_jc_javax_swing_InternalFrameFocusTraversalPolicy$sub_nonrefs;
typedef struct _jc_javax_swing_InternalFrameFocusTraversalPolicy$refs	_jc_javax_swing_InternalFrameFocusTraversalPolicy$refs;
typedef struct _jc_javax_swing_InternalFrameFocusTraversalPolicy$nonrefs	_jc_javax_swing_InternalFrameFocusTraversalPolicy$nonrefs;
typedef struct _jc_javax_swing_InternalFrameFocusTraversalPolicy$object	_jc_javax_swing_InternalFrameFocusTraversalPolicy$object;

typedef const struct _jc_javax_swing_InternalFrameFocusTraversalPolicy$vmethods	_jc_javax_swing_InternalFrameFocusTraversalPolicy$vmethods;
typedef const struct _jc_javax_swing_InternalFrameFocusTraversalPolicy$vtable	_jc_javax_swing_InternalFrameFocusTraversalPolicy$vtable;
typedef const struct _jc_javax_swing_InternalFrameFocusTraversalPolicy$vtype	_jc_javax_swing_InternalFrameFocusTraversalPolicy$vtype;

// Constructors
extern void _jc_javax_swing_InternalFrameFocusTraversalPolicy$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_InternalFrameFocusTraversalPolicy$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_Component$object *_jc_javax_swing_InternalFrameFocusTraversalPolicy$method$getInitialComponent$4f44bd9e24dac6b8(_jc_env *, struct _jc_javax_swing_InternalFrameFocusTraversalPolicy$object *, struct _jc_javax_swing_JInternalFrame$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_InternalFrameFocusTraversalPolicy$method_info$getInitialComponent$4f44bd9e24dac6b8;

// Virtual methods structure
struct _jc_javax_swing_InternalFrameFocusTraversalPolicy$vmethods {
	struct _jc_java_awt_Component$object	*(*getInitialComponent$4f44bd9e24dac6b8)(_jc_env *, struct _jc_javax_swing_InternalFrameFocusTraversalPolicy$object *, struct _jc_javax_swing_JInternalFrame$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_InternalFrameFocusTraversalPolicy$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_FocusTraversalPolicy$vmethods	java_awt_FocusTraversalPolicy;
	_jc_javax_swing_InternalFrameFocusTraversalPolicy$vmethods	javax_swing_InternalFrameFocusTraversalPolicy;
};

// Vtype
struct _jc_javax_swing_InternalFrameFocusTraversalPolicy$vtype {
	_jc_type			type;
	_jc_javax_swing_InternalFrameFocusTraversalPolicy$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_InternalFrameFocusTraversalPolicy$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_InternalFrameFocusTraversalPolicy$refs {
    _jc_javax_swing_InternalFrameFocusTraversalPolicy$sub_refs	javax_swing_InternalFrameFocusTraversalPolicy;
    _jc_java_awt_FocusTraversalPolicy$sub_refs	java_awt_FocusTraversalPolicy;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_InternalFrameFocusTraversalPolicy$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_InternalFrameFocusTraversalPolicy$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_FocusTraversalPolicy$sub_nonrefs	java_awt_FocusTraversalPolicy;
    _jc_javax_swing_InternalFrameFocusTraversalPolicy$sub_nonrefs	javax_swing_InternalFrameFocusTraversalPolicy;
};

// Object instance structure
struct _jc_javax_swing_InternalFrameFocusTraversalPolicy$object {
	_jc_javax_swing_InternalFrameFocusTraversalPolicy$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_InternalFrameFocusTraversalPolicy$vtype	*vtype;
	_jc_javax_swing_InternalFrameFocusTraversalPolicy$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_InternalFrameFocusTraversalPolicy$vtype _jc_javax_swing_InternalFrameFocusTraversalPolicy$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_InternalFrameFocusTraversalPolicy, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_InternalFrameFocusTraversalPolicy$class_object;

#endif	/* _JC_javax_swing_InternalFrameFocusTraversalPolicy_H_ */
